LayerXBlameEngine class
Analyzes a log entry and attributes the most likely owner of the problem.
Pure and stateless. Returns null for non-actionable levels
(verbose/debug/info/success).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
analyze(
LayerXLogEntry log) → LayerXBlameInfo? -
Returns a LayerXBlameInfo for
log, ornullwhen no blame is warranted.